==> nextcloud-28.0.6.tar.bz2: nextcloud/apps/circles/l10n/ro.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Ai șters {circle}",
    "{author} deleted {circle}" : "{author} a șters {circle}",
    "You removed {member} from {circle}" : "Ai îndepărtat pe {member} din {circle}",
    "You joined {circle}" : "Te-ai alăturat cercului {circle}",
    "{member} joined {circle}" : "{member} s-a alăturat cercului {circle}",
    "You accepted the invitation to join {circle}" : "Ai acceptat invitația să te alături cercului {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} a acceptat invitația să se alăture cercului {circle}",
    "You added {member} as member to {circle}" : "Ai adăugat pe {member} ca membru în {circle}",
    "You have been added as member to {circle} by {author}" : "Ai fost adăugat ca membru în {circle} de {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} a fost adăugat ca membru în {circle} de {author}",
    "You added {external} to {circle}" : "Ai adăugat {external} în {circle}",
    "{external} has been added to {circle} by {author}" : "{external} a fost adăugat în {circle} de {author}",
    "You accepted {member}'s request to join {circle}" : "Ai acceptat cererea lui {member} de alăturare în {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Cererea ta de alăturare în {circle} a fost acceptată de {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Cererea lui {member} de alăturare în {circle} a fost acceptată de {author}",
    "You left {circle}" : "Ai părăsit {circle}",
    "{member} left {circle}" : "{member} a părăsit {circle}",
    "You declined the invitation to join {circle}" : "Ai declinat invitația de alăturare în {circle}",
    "{member} declined an invitation to join {circle}" : "{member} a declinat invitația de alăturare în {circle}",
    "You cancelled your request to join {circle}" : "Ai anulat cererea de a te alătura {circle}",
    "You have been removed from {circle} by {author}" : "Ai fost îndepărtat din {circle} de {author}",
    "{member} has been removed from {circle} by {author}" : "{member} a fost îndepărtat din {circle} de {author}",
    "You removed {external} from {circle}" : "Ai îndepărtat {external} din {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} a fost îndepărtat din {circle} de {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ai anulat invitația lui {member} de a se alătura {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Invitația ta de a te alătura {circle} a fost anulată de {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} a anulat invitația lui {member} de a se alătura {circle}",
    "You dismissed {member}'s request to join {circle}" : "Ai ignorat cererea lui {member} de a se alătura {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Cererea ta de a te alătura {circle} a fost ignorată de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Cererea lui {member} de a se alătura {circle} a fost ignorată de {author}",
    "You invited {member} to join {circle}" : "Ai invitat pe {member} să se alăture {circle}",
    "You have been invited to join {circle} by {author}" : "Ai fost invitat să te alături {circle} de {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} a fost invitat să se alăture {circle} de {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Ai schimbat nivelul lui {member} în {circle} la %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} a schimbat nivelul tău în {circle} la %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} a schimbat nivelul lui {member} în {circle} la %1$s",
    "You sent a request to join {circle}" : "Ai trimis o cerere să te alături {circle}",
    "{member} sent a request to join {circle}" : "{member} a trimis o cerere să se alăture {circle}",
    "You are the new owner of {circle}" : "Ești noul proprietar al {circle}",
    "{member} is the new owner of {circle}" : "{member} este noul proprietar al {circle}",
    "Shared to Circles" : "Distribuit în Cercuri",
    "Single" : "Singur",
    "Personal" : "Personal",
    "System" : "Sistem",
    "Visible" : "Vizibil",
    "Open" : "Deschide",
    "Invite" : "Invită",
    "Friends" : "Prieteni",
    "Password protected" : "Protejat cu parolă",
    "No Owner" : "Niciun proprietar",
    "Hidden" : "Ascuns",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federated",
    "Mount point" : "Punct de montare",
    "Nextcloud Account" : "Cont Nextcloud",
    "Nextcloud Group" : "Grup Nextcloud",
    "Email address" : "Email",
    "Contact" : "Contact",
    "Circle" : "Cerc",
    "Nextcloud App" : "Aplicație Nextcloud",
    "Member" : "Membru",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Proprietar",
    "%s shared »%s« with you." : "%s a împărțit »%s« cu tine.",
    "%s shared »%s« with \"%s\"." : "%s a partejat »%s« cu \"%s\".",
    "%s on %s" : "%s pe %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat »%2$s« cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partajat »%2$s« cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access »%1$s« shared to you by %2$s" : "Parola pentru a accesa »%1$s« partajată cu tine de către %2$s",
    "Password to access »%s«" : "Parola pentru access »%s«",
    "It is protected with the following password:" : "Este protejat cu urmatoarea parolă:",
    "%1$s via %2$s" : "%1$sprin %2$s",
    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
    "Open »%s«" : "Deschide »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partajat mai multe fișiere cu tine.\nTrebuie să fi primit deja un mail separat cu linkul de acces.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s a partajat mai multe fișiere cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access files shared to you by %1$s" : "Parola pentru fișierele partajate de %1$s",
    "Password to access files" : "Parola pentru accesarea fișierelor",
    "%s shared multiple files with \"%s\"." : "%s a partajat mai multe fișiere cu \"%s\".",
    "%s shared multiple files with you." : "%s a partajat mai multe fișiere cu tine.",
    "Nextcloud Initialization" : "Inițializare Nextcloud",
    "Circles App Initialization" : "Inițializare aplicație Cercuri",
    "Fresh installation status" : "Statusul noii instalări",
    "Building Local Database" : "Se creează baza de date locală",
    "Testing Basic Circle Creation" : "Se testează crearea Cercului de bază",
    "Adding local users and moderators" : "Se adaugă utilizatorii locali și moderatorii",
    "This feature is not available for personal circles" : "Această caracteristică nu este disponibilă pentru cercurile personale",
    "This member is not a moderator" : "Acest membru nu este un moderator",
    "Insufficient privileges" : "Privilegii insuficiente",
    "This member does not exist" : "Acest membru nu există",
    "Level cannot be changed for this type of member" : "Nivelul nu poate fi schimbat pentru acest tip de membru",
    "You are already a member of this circle" : "Ești deja membru în acest cerc",
    "You have been blocked from this circle" : "Ai fost blocat din acest cerc",
    "The account is already a member of this circle" : "Contul este deja membru al acestui cerc",
    "The account has already been invited into this circle" : "Contul a fost deja invitat la acest cerc",
    "You are now a member of the Circle \"%2$s\"" : "Sunteți acum membru al Cercului \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Ați fost invitat de %1$s în Cercul \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s a solicitat să fie membru al Cercului \"%2$s\"",
    "Accept" : "Accept",
    "Refuse" : "Refuză",
    "Leave the circle" : "Părăsește cercul",
    "%s" : "%s",
    "%s owned by %s" : "%s proprietatea lui %s",
    "%s shared a file with \"%s\"." : "%s a partajat un fișier cu \"%s\".",
    "%s shared a file with you." : "%s a partajat un fișier cu tine.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat ceva cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s a partajat ceva cu tine. Trebuie să fi primit un email separat cu linkul de acces.",
    "Password to access content shared with you by %1$s" : "Parola pentru accesarea conținutului partajat de %1$s",
    "Password to access content" : "Parola pentru accesarea conținutului",
    "Bring cloud-users closer together." : "Adu utilizatorii cloud-ului mai aproape.",
    "No files in here" : "Nu sunt fișiere aici",
    "No entries found in this folder" : "Nici o intrare găsită în acest folder",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "Circles" : "Cercuri",
    "Circles' files" : "Fișierele cercului",
    "Select circles to filter by" : "Selectează cercuri pentru filtrare",
    "No circles found" : "Nu am găsit cercuri",
    "Please select circles to filter by" : "Te rog să alegi cercuri pentru filtrare",
    "No files found for the selected circles" : "Nu am găsit fișiere pentru cercurile selectate",
    "You created the circle {circle}" : "Ai creat cercul {circle}",
    "{author} created the circle {circle}" : "{author} a creat cercul {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "La evenimente care au loc în <strong>Cercul</strong> din care faceți parte",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Orice eveniment important într-un <strong>Cerc</strong> pe care îl moderezi",
    "On global events happening in any <strong>Circle</strong>" : "La evenimente globale care au loc în orice <strong>Cerc</strong>",
    "Join Request" : "Alăturați-vă solicitării",
    "Password Protected" : "Protejat prin parolă",
    "Circle Invite" : "Invitație la Cerc",
    "Email Address" : "Adresă de mail",
    "Circle not found" : "Cercul nu a fost găsit",
    "Circle not found " : "Cercul nu există",
    "This account is already a member of the circle" : "Acest cont este deja membru al cercului",
    "Federated link not found" : "Legătura federată nu a fost găsită",
    "The circle is not federated" : "Cercul nu este federat",
    "You cannot join this circle" : "Nu te poți alătura acestui cerc",
    "This member is the owner of the circle" : "Acest membru este proprietarul cercului",
    "%s (Circle owned by %s)" : "%s (Cerc proprietatea %s)",
    "Personal Circle" : "Cerc Personal",
    "You need a specify a type of circle" : "Trebuie specificat un tip de cerc",
    "A circle with that name exists" : "Un cerc cu acel nume există deja",
    "This member is not the owner of the circle" : "Acest membru nu este proprietarul cercului",
    "This member is not an admin of the circle" : "Acest membru nu este un administrator al cercului",
    "Group contains too many members" : "Grupul conține prea mulți membri",
    "This group does not exist" : "Acest grup nu există",
    "This group is already linked to the circle" : "Acest grup este deja legat de cerc",
    "You cannot edit level in a personal circle" : "Nu poti modifica nivelul într-un cerc personal",
    "Group cannot be set as owner of a circle" : "Un grup nu poate fi desemnat proprietar al unui cerc",
    "now" : "acum",
    "This account does not exist" : "Acest cont nu există",
    "Email format is not valid" : "Formatul de Email nu este valid",
    "This contact is not available" : "Acest contact nu este disponibil",
    "You have no permission to create a new circle" : "Nu aveți permisiunea de a crea un cerc nou",
    "This item is already shared with this circle" : "Elementul este deja partajat cu acest cerc",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cercuri permite utilizatorilor să-ți creeze propriile grupuri de colegi/prieteni.\nAcele grupuri (sau \"cercuri\") pot fi folosite în orice aplicație în scop de partajare."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/circles/l10n/ro.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Ai șters {circle}",
    "{author} deleted {circle}" : "{author} a șters {circle}",
    "You removed {member} from {circle}" : "Ai îndepărtat pe {member} din {circle}",
    "You joined {circle}" : "Te-ai alăturat cercului {circle}",
    "{member} joined {circle}" : "{member} s-a alăturat cercului {circle}",
    "You accepted the invitation to join {circle}" : "Ai acceptat invitația să te alături cercului {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} a acceptat invitația să se alăture cercului {circle}",
    "You added {member} as member to {circle}" : "Ai adăugat pe {member} ca membru în {circle}",
    "You have been added as member to {circle} by {author}" : "Ai fost adăugat ca membru în {circle} de {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} a fost adăugat ca membru în {circle} de {author}",
    "You added {external} to {circle}" : "Ai adăugat {external} în {circle}",
    "{external} has been added to {circle} by {author}" : "{external} a fost adăugat în {circle} de {author}",
    "You accepted {member}'s request to join {circle}" : "Ai acceptat cererea lui {member} de alăturare în {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Cererea ta de alăturare în {circle} a fost acceptată de {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Cererea lui {member} de alăturare în {circle} a fost acceptată de {author}",
    "You left {circle}" : "Ai părăsit {circle}",
    "{member} left {circle}" : "{member} a părăsit {circle}",
    "You declined the invitation to join {circle}" : "Ai declinat invitația de alăturare în {circle}",
    "{member} declined an invitation to join {circle}" : "{member} a declinat invitația de alăturare în {circle}",
    "You cancelled your request to join {circle}" : "Ai anulat cererea de a te alătura {circle}",
    "You have been removed from {circle} by {author}" : "Ai fost îndepărtat din {circle} de {author}",
    "{member} has been removed from {circle} by {author}" : "{member} a fost îndepărtat din {circle} de {author}",
    "You removed {external} from {circle}" : "Ai îndepărtat {external} din {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} a fost îndepărtat din {circle} de {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ai anulat invitația lui {member} de a se alătura {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Invitația ta de a te alătura {circle} a fost anulată de {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} a anulat invitația lui {member} de a se alătura {circle}",
    "You dismissed {member}'s request to join {circle}" : "Ai ignorat cererea lui {member} de a se alătura {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Cererea ta de a te alătura {circle} a fost ignorată de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Cererea lui {member} de a se alătura {circle} a fost ignorată de {author}",
    "You invited {member} to join {circle}" : "Ai invitat pe {member} să se alăture {circle}",
    "You have been invited to join {circle} by {author}" : "Ai fost invitat să te alături {circle} de {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} a fost invitat să se alăture {circle} de {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Ai schimbat nivelul lui {member} în {circle} la %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} a schimbat nivelul tău în {circle} la %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} a schimbat nivelul lui {member} în {circle} la %1$s",
    "You sent a request to join {circle}" : "Ai trimis o cerere să te alături {circle}",
    "{member} sent a request to join {circle}" : "{member} a trimis o cerere să se alăture {circle}",
    "You are the new owner of {circle}" : "Ești noul proprietar al {circle}",
    "{member} is the new owner of {circle}" : "{member} este noul proprietar al {circle}",
    "Single" : "Singur",
    "Personal" : "Personal",
    "System" : "Sistem",
    "Visible" : "Vizibil",
    "Open" : "Deschide",
    "Invite" : "Invită",
    "Friends" : "Prieteni",
    "Password protected" : "Protejat cu parolă",
    "No Owner" : "Niciun proprietar",
    "Hidden" : "Ascuns",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federated",
    "Mount point" : "Punct de montare",
    "Nextcloud Account" : "Cont Nextcloud",
    "Nextcloud Group" : "Grup Nextcloud",
    "Email address" : "Email",
    "Contact" : "Contact",
    "Team" : "Echipă",
    "Nextcloud App" : "Aplicație Nextcloud",
    "Member" : "Membru",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Proprietar",
    "%s shared »%s« with you." : "%s a împărțit »%s« cu tine.",
    "%s shared »%s« with \"%s\"." : "%s a partejat »%s« cu \"%s\".",
    "%s on %s" : "%s pe %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat »%2$s« cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partajat »%2$s« cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access »%1$s« shared to you by %2$s" : "Parola pentru a accesa »%1$s« partajată cu tine de către %2$s",
    "Password to access »%s«" : "Parola pentru access »%s«",
    "It is protected with the following password:" : "Este protejat cu urmatoarea parolă:",
    "%1$s via %2$s" : "%1$sprin %2$s",
    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
    "Open »%s«" : "Deschide »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partajat mai multe fișiere cu tine.\nTrebuie să fi primit deja un mail separat cu linkul de acces.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s a partajat mai multe fișiere cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access files shared to you by %1$s" : "Parola pentru fișierele partajate de %1$s",
    "Password to access files" : "Parola pentru accesarea fișierelor",
    "%s shared multiple files with \"%s\"." : "%s a partajat mai multe fișiere cu \"%s\".",
    "%s shared multiple files with you." : "%s a partajat mai multe fișiere cu tine.",
    "Nextcloud Initialization" : "Inițializare Nextcloud",
    "Circles App Initialization" : "Inițializare aplicație Cercuri",
    "Fresh installation status" : "Statusul noii instalări",
    "Building Local Database" : "Se creează baza de date locală",
    "Testing Basic Circle Creation" : "Se testează crearea Cercului de bază",
    "Adding local users and moderators" : "Se adaugă utilizatorii locali și moderatorii",
    "This feature is not available for personal circles" : "Această caracteristică nu este disponibilă pentru cercurile personale",
    "This member is not a moderator" : "Acest membru nu este un moderator",
    "Insufficient privileges" : "Privilegii insuficiente",
    "This member does not exist" : "Acest membru nu există",
    "Level cannot be changed for this type of member" : "Nivelul nu poate fi schimbat pentru acest tip de membru",
    "You are already a member of this circle" : "Ești deja membru în acest cerc",
    "You have been blocked from this circle" : "Ai fost blocat din acest cerc",
    "The account is already a member of this circle" : "Contul este deja membru al acestui cerc",
    "The account has already been invited into this circle" : "Contul a fost deja invitat la acest cerc",
    "Accept" : "Accept",
    "Refuse" : "Refuză",
    "%s" : "%s",
    "%s owned by %s" : "%s proprietatea lui %s",
    "%s shared a file with \"%s\"." : "%s a partajat un fișier cu \"%s\".",
    "%s shared a file with you." : "%s a partajat un fișier cu tine.",
    "Open %s" : "Deschide %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat ceva cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s a partajat ceva cu tine. Trebuie să fi primit un email separat cu linkul de acces.",
    "Password to access content shared with you by %1$s" : "Parola pentru accesarea conținutului partajat de %1$s",
    "Password to access content" : "Parola pentru accesarea conținutului",
    "Bring cloud-users closer together." : "Adu utilizatorii cloud-ului mai aproape.",
    "Loading…" : "Se încarcă...",
    "No files in here" : "Nu sunt fișiere aici",
    "No entries found in this folder" : "Nici o intrare găsită în acest folder",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "Shared to Circles" : "Distribuit în Cercuri",
    "Circle" : "Cerc"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
